import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { CreateLocalGatewayRouteTableRequest, CreateLocalGatewayRouteTableResult } from "../models/models_1";
/**
 * The input for {@link CreateLocalGatewayRouteTableCommand}.
 */
export interface CreateLocalGatewayRouteTableCommandInput extends CreateLocalGatewayRouteTableRequest {
}
/**
 * The output of {@link CreateLocalGatewayRouteTableCommand}.
 */
export interface CreateLocalGatewayRouteTableCommandOutput extends CreateLocalGatewayRouteTableResult, __MetadataBearer {
}
/**
 * <p>
 *       Creates a local gateway route table.
 *       </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, CreateLocalGatewayRouteTableCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, CreateLocalGatewayRouteTableCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new CreateLocalGatewayRouteTableCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateLocalGatewayRouteTableCommandInput} for command's `input` shape.
 * @see {@link CreateLocalGatewayRouteTableCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 */
export declare class CreateLocalGatewayRouteTableCommand extends $Command<CreateLocalGatewayRouteTableCommandInput, CreateLocalGatewayRouteTableCommandOutput, EC2ClientResolvedConfig> {
    readonly input: CreateLocalGatewayRouteTableCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: CreateLocalGatewayRouteTableCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<CreateLocalGatewayRouteTableCommandInput, CreateLocalGatewayRouteTableCommandOutput>;
    private serialize;
    private deserialize;
}
