import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { MoveByoipCidrToIpamRequest, MoveByoipCidrToIpamResult } from "../models/models_6";
/**
 * The input for {@link MoveByoipCidrToIpamCommand}.
 */
export interface MoveByoipCidrToIpamCommandInput extends MoveByoipCidrToIpamRequest {
}
/**
 * The output of {@link MoveByoipCidrToIpamCommand}.
 */
export interface MoveByoipCidrToIpamCommandOutput extends MoveByoipCidrToIpamResult, __MetadataBearer {
}
/**
 * <p>Move a BYOIPv4 CIDR to IPAM from a public IPv4 pool.</p>
 *          <p>If you already have a BYOIPv4 CIDR with Amazon Web Services, you can move the CIDR to IPAM from a public IPv4 pool. You cannot move an IPv6 CIDR to IPAM. If you are bringing a new IP address to Amazon Web Services for the first time, complete the steps in <a href="https://docs.aws.amazon.com/vpc/latest/ipam/tutorials-byoip-ipam.html">Tutorial: BYOIP address CIDRs to IPAM</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, MoveByoipCidrToIpamCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, MoveByoipCidrToIpamCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new MoveByoipCidrToIpamCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link MoveByoipCidrToIpamCommandInput} for command's `input` shape.
 * @see {@link MoveByoipCidrToIpamCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 */
export declare class MoveByoipCidrToIpamCommand extends $Command<MoveByoipCidrToIpamCommandInput, MoveByoipCidrToIpamCommandOutput, EC2ClientResolvedConfig> {
    readonly input: MoveByoipCidrToIpamCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: MoveByoipCidrToIpamCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<MoveByoipCidrToIpamCommandInput, MoveByoipCidrToIpamCommandOutput>;
    private serialize;
    private deserialize;
}
